@@ -1,10 +1,10 @@
 #
-# $Id: Simple.pm 345 2012-01-25 21:48:03Z gomor $
+# $Id: Simple.pm,v 6683a807d2d6 2016/10/05 16:54:08 gomor $
 #
 package Net::Frame::Simple;
 use warnings; use strict;
 
-our $VERSION = '1.05';
+our $VERSION = '1.07';
 
 use Class::Gomor::Array;
 use Exporter;
@@ -20,6 +20,7 @@ our @AS = qw(
    firstLayer
    padding
    ref
+   truncated
    _canMatchLayer
    _getKey
    _getKeyReverse
@@ -52,6 +53,7 @@ sub new {
    my $self = shift->SUPER::new(
       timestamp  => _gettimeofday(),
       firstLayer => NF_LAYER_UNKNOWN,
+      truncated  => 0,
       layers     => [],
       @_,
    );
@@ -229,6 +231,9 @@ sub _getPadding {
       $padding = substr($self->[$__raw], $tLen, $pLen);
       $self->[$__padding] = $padding;
    }
+   else {
+      $self->[$__truncated] = 1;
+   }
 
    # Now, split padding between true padding and true payload
    my $payloadLength = length($last->payload);
@@ -358,8 +363,17 @@ sub print {
 sub dump {
    my $self = shift;
 
+   my $last;
    my $raw = '';
-   $raw .= $_->raw for @{$self->[$__layers]};
+   for my $l (@{$self->[$__layers]}) {
+      $raw .= $l->raw;
+      $last = $l;
+   }
+
+   if ($last && defined($last->payload)) {
+      $raw .= $last->payload;
+   }
+
    $raw .= $self->[$__padding] if $self->[$__padding];
 
    CORE::unpack('H*', $raw);
@@ -450,6 +464,10 @@ We cannot know by which layer a frame begins, so this tells how to start unpacki
 
 Sometimes, frames are padded to achieve 60 bytes in length. The padding will be stored here, or if you craft a frame, you can manually add your own padding.
 
+=item B<truncated>
+
+A binary flag stating when a raw frame has been truncated (or not).
+
 =item B<reply>
 
 When the B<recv> method is called, and a corresponding reply has been found, it is stored here.
@@ -531,7 +549,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2012, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
